@@ -1791,8 +1791,6 @@ def forEachUnitRun(
 def runlinear(x, y, nPredics, fwerRate=0.25, adjust_method="fdr_bh"):
     results = {}
 
-    print("runLinear Phase I")
-
     mask = np.ones(x.shape[1], dtype=bool)
     # denote linear dependent columns
     ld_col = detectLDcol(x)
@@ -1901,7 +1899,6 @@ def runGlmnet(
     intercept=True,
     zeroSDCut=10 ** (-20),
 ):
-    print("runGlmnet Phase I")
     results = {}
     nBeta = x.shape[1]
 
@@ -1946,7 +1943,7 @@ def runGlmnet(
 
 
 def groupBetaToFullBeta(nTaxa, nPredics, unSelectList, newBetaNoInt):
-    print("Called groupBetaToFullBeta")
+
     results = {}
     unSelectList = np.unique(np.sort(unSelectList))
     nUnSelec = len(unSelectList)
@@ -2064,8 +2061,6 @@ def bootResuHDCI(
             xSub = x[rowToKeep, :]
             ySub = y[rowToKeep]
 
-            print("runLinear Phase 2")
-
             # remove all constant column see email thread
             mask = np.ones(xSub.shape[1], dtype=bool)
             # denote linear dependent columns
@@ -2152,8 +2147,6 @@ def bootResuHDCI(
             xSub = x[rowToKeep, :]
             ySub = y[rowToKeep]
 
-            print("runGlmnet Phase 2")
-
             bootResu = runBootLassoHDCI(
                 x=xSub,
                 y=ySub,
